==> percona-server-5.6_5.6.49-89.0.orig.tar.gz: percona-server-5.6.49-89.0/storage/ndb/cmake/ndb_require_variable.cmake <==
# Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2.0,
# as published by the Free Software Foundation.
#
# This program is also distributed with certain software (including
# but not limited to OpenSSL) that is licensed under separate terms,
# as designated in a particular file or component or in included license
# documentation.  The authors of MySQL hereby grant you an additional
# permission to link the program and your derivative works with the
# separately licensed software that they have included with MySQL.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License, version 2.0, for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


# NDB_REQUIRE_VARIABLE
#
# Check that the variable with given name is defined
#
MACRO(NDB_REQUIRE_VARIABLE variable_name)
  MESSAGE(STATUS "Checking variable ${variable_name} required by NDB")
  IF(NOT DEFINED "${variable_name}")
    MESSAGE(FATAL_ERROR "The variable ${variable_name} is required "
                         "to build NDB")
  ENDIF()
ENDMACRO()

==> percona-server-5.7_5.7.33-36.orig.tar.gz: percona-server-5.7.33-36/storage/ndb/cmake/ndb_require_variable.cmake <==
# Copyright (c) 2010, 2016, Oracle and/or its affiliates. All rights reserved.
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2.0,
# as published by the Free Software Foundation.
#
# This program is also distributed with certain software (including
# but not limited to OpenSSL) that is licensed under separate terms,
# as designated in a particular file or component or in included license
# documentation.  The authors of MySQL hereby grant you an additional
# permission to link the program and your derivative works with the
# separately licensed software that they have included with MySQL.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License, version 2.0, for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


# NDB_REQUIRE_VARIABLE
#
# Check that the variable with given name is defined
#
MACRO(NDB_REQUIRE_VARIABLE variable_name)
  #MESSAGE(STATUS "Checking variable ${variable_name} required by NDB")
  IF("${${variable_name}}" STREQUAL "")
    MESSAGE(FATAL_ERROR "The variable ${variable_name} is required "
                         "to build NDB")
  ENDIF()
ENDMACRO()
